%{!?kernel_version: %{expand: %%define kernel_version %(uname -r)}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | perl -pe 's/^.*-(.*?)$/$1/g')}}

# Definitions for symvers files.
%define vmw_symvers_dir usr/lib/vmware-tools/symvers
%define bld_symvers_file Modules.symvers

Name:         vmware-tools-vsock
BuildRequires: kernel-source kernel-syms gcc make perl
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vsock kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      9.3.4.0
Release:      5.sles10
Source1:      vsock-configModule.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

Source0:      vsock.tar
Source2:      vsock-vmware-PLDP-spec

%define kernel_version %(uname -r|perl -pe 's/^(.*)-.*?$/$1/g')

# Lock down flavors to build to just the current flavor.
%{expand: %%define current_flavor %(uname -r|perl -pe 's/^.*-(.*)$/$1/g')}
%suse_kernel_module_package -s %{SOURCE2} -x %{current_flavor}

%prep
%setup -n vsock-only

%build
for flavor in %flavors_to_build; do
  VMCI_SYMVERS_FILE=/%{vmw_symvers_dir}/vmci-%{kernel_version}-$flavor

  rm -rf ../$flavor ../vsock.o
  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor clean

  # For modules that depend on vmci, copy in the vmci symvers file
  # or die trying.
  # XXX: I can only handle dependency on one module's symvers file.
  if [ "vsock" = "vsock" -o "vsock" = "vmhgfs" ]; then
     if [ ! -e $VMCI_SYMVERS_FILE ]; then
        echo
        echo
        echo "
ERROR: Could not find $VMCI_SYMVERS_FILE.  This package relies on kernel symbols for the currently running kernel that are built from the vmware-tools-vmci source RPM package.  Please do the following:

- Rebuild the vmware-tools-vmci source RPM package.
- Install the resulting binary RPM from /usr/src/packages/RPMS/\$ARCH/.
- Rebuild this package again."
        echo
        echo
        exit 1
     fi
     cp -f $VMCI_SYMVERS_FILE ./%{bld_symvers_file}
  fi

  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor
  mkdir ../$flavor
  cp ../vsock.o ../$flavor

  # Take the symvers file with us as well.
  cp ./%{bld_symvers_file} ../$flavor/%{bld_symvers_file}
done

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
for flavor in %flavors_to_build; do
  vsock_SYMVERS_FILE=%{vmw_symvers_dir}/vsock-%{kernel_version}-$flavor
  # Install the module and symvers file.
  install -m 644 -D ../$flavor/vsock.o $RPM_BUILD_ROOT/lib/modules/%{kernel_version}-$flavor/updates/vsock.ko
  install -m 644 -D ../$flavor/%{bld_symvers_file} $RPM_BUILD_ROOT/$vsock_SYMVERS_FILE
done
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vsock.  The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%package common
Summary:      Contains the common files used by all the vsock kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      5.sles10
Version:      9.0.15

%description common
 This package contains the common system configuration and scripts responsible for loading the vsock kernel module.  The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/insserv -r vsock >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,sle,10 --kernel=%{kernel_version} --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,sle,10 --dbDelAnswer VSOCK_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,sle,10 --dbAddAnswer VSOCK_NAME,vsock
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-config.pl --os=linux,sle,10 --kernel=%{kernel_version} --toConfigure=vsock
if [ -e /etc/init.d/vsock ]; then
   /sbin/insserv -f vsock >/dev/null 2>&1
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/insserv -r vsock >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,sle,10 --kernel=%{kernel_version} --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,sle,10 --dbDelAnswer VSOCK_NAME
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-config.pl
/etc/init.d/vsock
